@@ -8,18 +8,10 @@ from .serverextension import load_jupyter_server_extension
 
 
 def _jupyter_server_extension_paths():
-    return [
-        {
-            'module': 'jupyterlab'
-        }
-    ]
+    return [{"module": "jupyterlab"}]
 
 
 def _jupyter_server_extension_points():
     from .labapp import LabApp
-    return [
-        {
-            'module': 'jupyterlab',
-            'app': LabApp
-        }
-    ]
\ No newline at end of file
+
+    return [{"module": "jupyterlab", "app": LabApp}]
