@@ -27,7 +27,7 @@ from threading import Event
 from urllib.error import URLError
 from urllib.request import Request, quote, urljoin, urlopen
 
-from jupyter_core.paths import jupyter_config_dir
+from jupyter_core.paths import jupyter_config_path
 from jupyter_server.extension.serverextension import (
     GREEN_ENABLED,
     GREEN_OK,
@@ -141,14 +141,14 @@ def pjoin(*args):
 def get_user_settings_dir():
     """Get the configured JupyterLab user settings directory."""
     settings_dir = os.environ.get("JUPYTERLAB_SETTINGS_DIR")
-    settings_dir = settings_dir or pjoin(jupyter_config_dir(), "lab", "user-settings")
+    settings_dir = settings_dir or pjoin(jupyter_config_path()[0], "lab", "user-settings")
     return osp.abspath(settings_dir)
 
 
 def get_workspaces_dir():
     """Get the configured JupyterLab workspaces directory."""
     workspaces_dir = os.environ.get("JUPYTERLAB_WORKSPACES_DIR")
-    workspaces_dir = workspaces_dir or pjoin(jupyter_config_dir(), "lab", "workspaces")
+    workspaces_dir = workspaces_dir or pjoin(jupyter_config_path()[0], "lab", "workspaces")
     return osp.abspath(workspaces_dir)
 
 
@@ -354,14 +354,6 @@ class AppOptions(HasTraits):
 
     splice_source = Bool(False, help="Splice source packages into app directory.")
 
-    skip_full_build_check = Bool(
-        False,
-        help=(
-            "If true, perform only a quick check that the lab build is up to date."
-            " If false, perform a thorough check, which verifies extension contents."
-        ),
-    )
-
     @default("logger")
     def _default_logger(self):
         return logging.getLogger("jupyterlab")
@@ -619,7 +611,6 @@ class _AppHandler(object):
         self.labextensions_path = options.labextensions_path
         self.kill_event = options.kill_event
         self.registry = options.registry
-        self.skip_full_build_check = options.skip_full_build_check
 
         # Do this last since it relies on other attributes
         self.info = self._get_app_info()
@@ -812,13 +803,11 @@ class _AppHandler(object):
             logger.info("\nBuild recommended, please run `jupyter lab build`:")
             [logger.info("    %s" % item) for item in messages]
 
-    def build_check(self, fast=None):
+    def build_check(self, fast=False):
         """Determine whether JupyterLab should be built.
 
         Returns a list of messages.
         """
-        if fast is None:
-            fast = self.skip_full_build_check
         app_dir = self.app_dir
         local = self.info["local_extensions"]
         linked = self.info["linked_packages"]
@@ -1374,7 +1363,7 @@ class _AppHandler(object):
         jlab = data["jupyterlab"]
 
         def format_path(path):
-            path = osp.relpath(path, osp.abspath(osp.realpath(pjoin(self.app_dir, "staging"))))
+            path = osp.relpath(path, pjoin(self.app_dir, "staging"))
             path = "file:" + path.replace(os.sep, "/")
             if os.name == "nt":
                 path = path.lower()
@@ -2332,10 +2321,11 @@ def _log_multiple_compat_errors(logger, errors_map):
     if outdated:
         logger.warn(
             "\n        ".join(
-                [
-                    "\n   The following extensions are outdated:",
-                    *outdated,
-                    '\n   Consider checking if an update is available for these packages.\n',
+                ["\n   The following extension are outdated:"]
+                + outdated
+                + [
+                    '\n   Consider running "jupyter labextension update --all" '
+                    "to check for updates.\n"
                 ]
             )
         )
